@@ -1,10 +1,5 @@
 """
-=========
-poliastro
-=========
-
 Utilities and Python wrappers for Orbital Mechanics
-
 """
 
-__version__ = "0.14.0"
+__version__ = "0.15.0"
